'***************************************************************************
'                  PROGRAM  EPIC1_1
'
'(c) Ing.Buero Lehmann, Fuerstenbergstrasse 8a, D-77756 Hausach, Germany
'   Tel. +49 (0)7831 452     Fax +49 (0)7831 96428    www.iL-online.de
'***************************************************************************
'
'This demo program is written for the PIC BASIC compiler iL_BAS16SES which
'supports PIC16F84 and PIC 16F628 to run on EPIC-1 a Low Cost PIC development
'system available at LEXTRONIC (France).
'
'It turns on and off the LEDs in verious ways. All JP2s must be set to the right
'side to connect the LEDs to port RB. For programming shove SW1 to SW3 to upper
'position for running slide then down.
'
'The buttons on RA0 to RA3 select the different modes. In programming this is 
'called state machine. The actual state is stored in variable STATE at location
'22H. Pressing RA1 state machine enters next state, RA1 turns state machine 
'to initial state.
'
'state 0 = initial state = point runs from right to left
'state 1                 = point runs from left to right
'state 2                 = bargraph runs form left to right
'state 3                 = bargraph runs from right to left
'state 4                 = bargraph runs vice versa
'
'RA2 increase speed

         define device 16f84,wdt_off
         xtal 4
         
         define count = $20            'count register
         define dir   = $21            'direction
         define state = $22            'state
         define speed = $23            'running speed
         define ii = $24               'for for-next loop
         
cold:
         goto start
         
init:    
         tris rb,0                     'all RB-Pins are output
         return
         
'KEY is entered if RA0 is pressed and it remains until RA0 is
'released
key:     
         wait 10                       'debounce for 10 ms
         if ra,0=1 then return         'not pressed
         inc state                     'select next state
         if state = 5 then  let state=0
keywait:
         if ra,0 = 0 then goto keywait 'until key released
         let count=0                   'starts allways new
         return
                      
setspeed:
         wait 10                       'debounce
         if ra,2=1 then return         'assumed not pressed                      
         dec speed
         if speed=0 then let speed=10
sspeedw:
         if ra,2=0 then goto sspeedw
         return
                  
start:
         gosub init                    'make all RB-Pins to output
         let state = 0
         let count = 1
         let speed = 10
loop:
         if ra,0=0 then gosub key      'Key is pressed
         if ra,1=0 then let state=0    'set initial state
         if ra,2=0 then gosub setspeed 
         output rb,count
         for ii=0 to speed
           wait 100
         next ii
         if state = 0 then goto state0
         if state = 1 then goto state1
         if state = 2 then goto state2
         if state = 3 then goto state3
         if state = 4 then goto state4
state0:         
         shl count
         if count=0 then let count = 1
         goto loop
state1:
         shr count
         if count=0 then let count = 128         
         goto loop

state2:
         if count=255 then goto state4a
         shl count                     'shift information to the left
         set count,0                   'set lowest bit to one
         goto loop
state3:
         if count=255 then goto state4a
         shr count                     'shift information to the right         
         set count,7                   'set highest bit to one
         goto loop
         
state4:
         if dir,0=0 then goto state2
         goto state3
state4a:
         toggle dir,0
         let count=0
         goto loop          